@@ -17,13 +17,7 @@ test_file_dir = absjoin(thisdir, '../../tests/test_files')
 # new ones should go here instead, others should be moved over
 test_pptx_dir = absjoin(thisdir, 'test_files')
 
-# new test pptx files ------------------
-ext_rels_pptx_path = absjoin(test_pptx_dir, 'ext-rels.pptx')
-shp_pos_and_size_pptx_path = absjoin(test_pptx_dir, 'shp-pos-and-size.pptx')
-
 # legacy test pptx files ---------------
-basic_pptx_path = absjoin(test_file_dir, 'test.pptx')
-italics_pptx_path = absjoin(test_file_dir, 'italic-runs.pptx')
 no_core_props_pptx_path = absjoin(test_file_dir, 'no-core-props.pptx')
 test_image_path = absjoin(test_file_dir, 'python-powered.png')
 
@@ -33,6 +27,13 @@ saved_pptx_path = absjoin(scratch_dir, 'test_out.pptx')
 test_text = "python-pptx was here!"
 
 
+def cls_qname(obj):
+    module_name = obj.__module__
+    cls_name = obj.__class__.__name__
+    qname = '%s.%s' % (module_name, cls_name)
+    return qname
+
+
 def test_pptx(name):
     """
     Return the absolute path to test .pptx file with root name *name*.
